==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ja\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""

]
, "Task, Tasks"
: [
  "タスク"

]
, "Percent"
: "パーセント"

, "Completed"
: "完了"

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: ""

, "Priority"
: "重要度"

, "Status, Status"
: [
  ""

]
, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "サマリー"

, "Due date"
: "期日"

, "Add Responsible ..."
: ""

, "Notes"
: "ノート"

, "Enter description..."
: "説明を入力してください..."

, "Percentage"
: "割合"

, "Tasks"
: "タスク"

, "to do list, to do lists"
: [
  "ToDoリスト"

]
, "to do lists"
: "ToDoリスト"

, "Quick Search"
: ""

, "Due Date"
: "期日"

, "Responsible"
: "責任担当"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "作成時間"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "選択されたタスクを本当に削除しますか？"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "タスクを追加しています..."

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: "%s のパーソナルタスク"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "タスク"

, "Status"
: ""

, "to do list"
: "ToDoリスト"

, "Do you really want to delete the selected task?"
: "選択されたタスクを本当に削除しますか？"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "サマリー"

, "Due date"
: "期日"

, "Priority"
: "重要度"

, "Organizer"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: "ノート"

, "Enter description..."
: "説明を入力してください..."

, "Percentage"
: "割合"

, "Status, Status"
: [
  ""

]
, "Completed"
: "完了"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "選択されたタスクを本当に削除しますか？"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "タスクを追加しています..."

, "Due Date"
: "期日"

, "Percent"
: "パーセント"

, "Responsible"
: "責任担当"

, "Task, Tasks"
: [
  "タスク"

]
, "Tasks"
: "タスク"

, "to do list, to do lists"
: [
  "ToDoリスト"

]
, "to do lists"
: "ToDoリスト"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "作成時間"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "%s のパーソナルタスク"

, "GENDER_Task"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "選択されたタスクを本当に削除しますか？"

, "Task"
: "タスク"

, "to do list"
: "ToDoリスト"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
